==> konoha0.9_350.zip: konoha0.9/class/konoha/knh_Connection__ubiql.c <==
/****************************************************************************
 * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER  
 * 
 * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
 *           (c) 2007       Akihide Takai <atatai at sourceforge.jp>
 *           (c) 2008-      Konoha Software Foundation  
 * All rights reserved.
 * 
 * You may choose one of the following two licenses when you use konoha. 
 * See www.konohaware.org/license.html for further information.
 * 
 * (1) GNU General Public License 2.0      (with    KONOHA_UNDER_GPL2)
 * (2) Konoha Software Foundation License 1.0
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER 
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 ****************************************************************************/

/* ************************************************************************ */

#include"commons.h"

/* ************************************************************************ */

#ifdef __cplusplus 
extern "C" {
#endif
	
/* ======================================================================== */
// char *url = "ubiql://(hostname)/(DB)";

knh_connptr_t* 
knh_Connection_open__ubiql(Ctx *ctx, knh_bytes_t url, char *uname, char *upwd)
{
	return NULL;
}

/* ------------------------------------------------------------------------ */

knh_bool_t knh_ResultSet_next__ubiql(Ctx *ctx, knh_rsptr_t *rsptr, ResultSet *b)
{
	return 0; /* if nothing */
}

/* ------------------------------------------------------------------------ */

void knh_ResultSet_free__ubiql(knh_rsptr_t *rsptr)
{

}

/* ------------------------------------------------------------------------ */

ResultSet* 
knh_Connection_query__ubiql(Ctx *ctx, knh_connptr_t *conn, char *sql)
{
	return (ResultSet*)KNH_NULL;
}

/* ------------------------------------------------------------------------ */

void knh_Connection_close__ubiql(Ctx *ctx, knh_connptr_t *conn)
{
	
}

/* ======================================================================== */

#ifdef __cplusplus
}
#endif

==> konoha0.9_365.zip: konoha0.9/class/konoha/knh_Connection__ubiql.c <==
/****************************************************************************
 * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER  
 * 
 * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
 *           (c) 2007       Akihide Takai <atatai at sourceforge.jp>
 *           (c) 2008-      Konoha Software Foundation  
 * All rights reserved.
 * 
 * You may choose one of the following two licenses when you use konoha. 
 * See www.konohaware.org/license.html for further information.
 * 
 * (1) GNU General Public License 2.0      (with    KONOHA_UNDER_GPL2)
 * (2) Konoha Software Foundation License 1.0
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER 
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 ****************************************************************************/

/* ************************************************************************ */

#include"commons.h"

/* ************************************************************************ */

#ifdef __cplusplus 
extern "C" {
#endif
	
/* ======================================================================== */
// char *url = "ubiql://(hostname)/(DB)";

knh_connptr_t* 
knh_Connection_open__ubiql(Ctx *ctx, knh_bytes_t url, char *uname, char *upwd)
{
	return NULL;
}

/* ------------------------------------------------------------------------ */

knh_bool_t knh_ResultSet_next__ubiql(Ctx *ctx, knh_rshdlr_t *rsptr, ResultSet *b)
{
	return 0; /* if nothing */
}

/* ------------------------------------------------------------------------ */

void knh_ResultSet_free__ubiql(knh_rshdlr_t *rsptr)
{

}

/* ------------------------------------------------------------------------ */

ResultSet* 
knh_Connection_query__ubiql(Ctx *ctx, knh_connptr_t *conn, char *sql)
{
	return (ResultSet*)KNH_NULL;
}

/* ------------------------------------------------------------------------ */

void knh_Connection_close__ubiql(Ctx *ctx, knh_connptr_t *conn)
{
	
}

/* ======================================================================== */

#ifdef __cplusplus
}
#endif
